import "./tasks/somatic.wdl" as somatic
import "./tasks/processSomatic.wdl" as processSomatic
import "./tasks/somaticFilter.wdl" as somaticFilter
import "./tasks/annovar.wdl" as annovar
import "./tasks/vcf2maf.wdl" as vcf2maf


workflow {{ project_name }} {
    
    String sample_id
    File normal_recaled_bam
    File tumor_recaled_bam
    File normal_recaled_bam_index
    File tumor_recaled_bam_index

    String varscan_docker
    String annovar_docker
    String maftools_docker
    String disk_size
    String cluster_config

    File ref_dir
    String fasta
    File dbmills_dir
    String db_mills
    File dbsnp_dir
    String dbsnp
    File regions
    File database
    

    call somatic.somatic as somatic {
        input:
        sample=sample_id,
        normal_bam=normal_recaled_bam,
        tumor_bam=tumor_recaled_bam,
        normal_bam_index=normal_recaled_bam_index,
        tumor_bam_index=tumor_recaled_bam_index,
        ref_dir=ref_dir,
        fasta=fasta,        
        docker=varscan_docker,	
        disk_size=disk_size,
        cluster_config=cluster_config
    }

    call processSomatic.processSomatic as processSomatic {
        input:
        sample=sample_id,
        varscan_snp=somatic.varscan_snp,
        varscan_indel=somatic.varscan_indel,     
        docker=varscan_docker,	
        disk_size=disk_size,
        cluster_config=cluster_config
    }

    call somaticFilter.somaticFilter as somaticFilter {
        input:
        sample=sample_id,
        varscan_snp_somatic_hc=processSomatic.varscan_snp_somatic_hc,
        varscan_snp_loh_hc=processSomatic.varscan_snp_loh_hc,
        varscan_indel_somatic_hc=processSomatic.varscan_indel_somatic_hc,
        varscan_indel_loh_hc=processSomatic.varscan_indel_loh_hc,
        varscan_indel=somatic.varscan_indel,   
        docker=varscan_docker,	
        disk_size=disk_size,
        cluster_config=cluster_config
    }

    call annovar.annovar as snp_somatic_annovar {
        input: 
        sample=sample_id,
        vcf=somaticFilter.varscan_snp_somatic_filter,
        database=database,
        docker=annovar_docker,
        cluster_config=cluster_config,
        disk_size=disk_size
    }

    call vcf2maf.vcf2maf as snp_somatic_vcf2maf {
        input:
        sample=sample_id,
        multianno_txt=snp_somatic_annovar.multianno_txt,
        docker=maftools_docker,
        cluster_config=cluster_config,
        disk_size=disk_size
    }
    
    call annovar.annovar as snp_loh_annovar {
        input: 
        sample=sample_id,
        vcf=somaticFilter.varscan_snp_loh_filter,
        database=database,
        docker=annovar_docker,
        cluster_config=cluster_config,
        disk_size=disk_size
    }

    call vcf2maf.vcf2maf as snp_loh_vcf2maf {
        input:
        sample=sample_id,
        multianno_txt=snp_loh_annovar.multianno_txt,
        docker=maftools_docker,
        cluster_config=cluster_config,
        disk_size=disk_size
    }
    
    call annovar.annovar as indel_somatic_annovar {
        input: 
        sample=sample_id,
        vcf=somaticFilter.varscan_indel_somatic_filter,
        database=database,
        docker=annovar_docker,
        cluster_config=cluster_config,
        disk_size=disk_size
    }

    call vcf2maf.vcf2maf as indel_somatic_vcf2maf {
        input:
        sample=sample_id,
        multianno_txt=indel_somatic_annovar.multianno_txt,
        docker=maftools_docker,
        cluster_config=cluster_config,
        disk_size=disk_size
    }
    
    call annovar.annovar as indel_loh_annovar {
        input: 
        sample=sample_id,
        vcf=somaticFilter.varscan_indel_loh_filter,
        database=database,
        docker=annovar_docker,
        cluster_config=cluster_config,
        disk_size=disk_size
    }

    call vcf2maf.vcf2maf as indel_loh_vcf2maf {
        input:
        sample=sample_id,
        multianno_txt=indel_loh_annovar.multianno_txt,
        docker=maftools_docker,
        cluster_config=cluster_config,
        disk_size=disk_size
    }
}